/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GeoLocatorInterface.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.geolocation.business;

import java.util.List;
import org.ow2.util.geolocation.business.entity.GeolocalisedProduct;

/**
 * Interface of the geolocalization EJB.
 * 
 * @author mancelin
 */
public interface GeoLocatorInterface {
    /**
     * Add a new record in the app.
     * @param ipAddress the address of the user.
     * @param productName the product name.
     * @param productVersion the version name.
     * @param email the email address of the user.
     * @param jreVendor the jre vendor.
     * @param jreVersion the jre version.
     * @param jvmName the jvm name.
     * @param jvmVendor the jvm vendor.
     * @param jvmVersion the jvm version.
     * @param osName the os.
     * @param osArch os architecture.
     * @param osVersion os version.
     * @param numProc the number of processors.
     * @return succeed
     */
    boolean addNewRecord(
            final String ipAddress,
            final String productName,
            final String productVersion,
            final String email,
            final String numProc,
            final String jreVersion,
            final String jreVendor,
            final String jvmVersion,
            final String jvmVendor,
            final String jvmName,
            final String osName,
            final String osArch,
            final String osVersion);
    /**
     * @param productName the product name.
     * @param productVersion the product version.
     * @return filtered list of products.
     */
    List getLocalisedProducts(java.lang.String productName, java.lang.String productVersion);
    /**
     * @return all products name.
     */
    List findAllProductsName();
    /**
     * @return all products versions.
     */
    List findAllProductsVersions();
    /**
     * Remove a product.
     * @param id the id product.
     */
    void removeProduct(Long id);

    /**
     * Add a managed product in the managed products list.
     * @param name name of the product.
     * @param version version of the product.
     * @return succeed
     */
    boolean addManagedProduct(final String name, final String version);

    /**
     *
     * @param productName the filter name.
     * @param productVersion the filter version.
     * @return all persited products with the right name and right version.
     */
    List findManagedProductsWithNameAndVersion(final String productName, final String productVersion);

    /**
     * Remove a managed product.
     * @param id the id of the managed product.
     */
    void removeManagedProduct(final Long id);

    /**
     * @return all persited managed products.
     */
    List findAllManagedProducts();

    /**
     * @param id id of the product.
     * @return a specific product.
     */
    GeolocalisedProduct findAProduct(final String id);

}
