/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GeolocalisedProduct.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.geolocation.business.entity;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToOne;
import javax.persistence.PrePersist;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

/**
 * A geolocalised product.
 * 
 * @author mancelin
 */
@Entity
public class GeolocalisedProduct implements Serializable {
    /**
     * The version UID.
     */
    private static final long serialVersionUID = 1L;
    /**
     * ID of the product.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    /**
     * Date of the record.
     */
    @Temporal(TemporalType.TIMESTAMP)
    private Date recordDate;
    /**
     * The name of the product.
     */
    @ManyToOne//(fetch = FetchType.EAGER)
    @JoinColumn(name = "productName_fk")
    private ProductName productName;
    /**
     * The version of the product.
     */
    @ManyToOne(fetch = FetchType.EAGER)
    @JoinColumn(name = "productVersion_fk")
    private ProductVersion productVersion;
    /**
     * TechnicalAttribute of the User computer.
     */
    @OneToOne
    @JoinColumn(name = "attributes_fk")
    private TechnicalAttributes attributes;
    /**
     * The ip address of the user.
     */
    private String ipAddress;
    /**
     * The email address of the user.
     */
    private String email;
    /**
     * The country code.
     */
    private String countryCode;
    /**
     * The country name.
     */
    private String countryName;
    /**
     * The region.
     */
    private String region;
    /**
     * The city.
     */
    private String city;
    /**
     * The postal code.
     */
    private String postalCode;
    /**
     * The latitude.
     */
    private float latitude;
    /**
     * The longitude.
     */
    private float longitude;
    /**
     * The dma code.
     */
    private int dmaCode;
    /**
     * The area code.
     */
    private int areaCode;
    /**
     * The metro code.
     */
    private int metroCode;
    /**
     * The region name.
     */
    private String regionName;
    /**
     * The timezone.
     */
    private String timezone;
    /**
     * @return the id of the product.
     */
    public Long getId() {
        return id;
    }
    /**
     * Set the id of the product.
     * @param id the id of the product.
     */
    public void setId(final Long id) {
        this.id = id;
    }
    /**
     * Set default data before persist phase.
     */
    @PrePersist
    private void setDefaultData() {
        recordDate = new Date();
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (id != null) {
            hash += id.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof GeolocalisedProduct)) {
            return false;
        }
        GeolocalisedProduct other = (GeolocalisedProduct) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "org.ow2.jonas.installers.geo.business.ipgeolocalisation.entity.GeolocalisedProduct[id=" + id
                + " name : " + this.getProductName()
                + " version : " + this.getProductVersion()
                + " IP : " + this.ipAddress
                + " email : " + this.email
                + " area : " + this.areaCode
                + " country : " + this.countryCode
                + " country : " + this.countryName
                + " dma : " + this.dmaCode
                + " latitude : " + this.latitude
                + " longitude : " + this.longitude
                + " metro : " + this.metroCode
                + " postal code : " + this.postalCode
                + " region : " + this.region
                + " region name : " + this.regionName
                + " timezone : " + this.timezone
                + "]";
    }

    /**
     * @return the countryCode
     */
    public String getCountryCode() {
        return countryCode;
    }

    /**
     * @param countryCode the countryCode to set
     */
    public void setCountryCode(final String countryCode) {
        this.countryCode = countryCode;
    }

    /**
     * @return the countryName
     */
    public String getCountryName() {
        return countryName;
    }

    /**
     * @param countryName the countryName to set
     */
    public void setCountryName(final String countryName) {
        this.countryName = countryName;
    }

    /**
     * @return the region
     */
    public String getRegion() {
        return region;
    }

    /**
     * @param region the region to set
     */
    public void setRegion(final String region) {
        this.region = region;
    }

    /**
     * @return the city
     */
    public String getCity() {
        return city;
    }

    /**
     * @param city the city to set
     */
    public void setCity(final String city) {
        this.city = city;
    }

    /**
     * @return the postalCode
     */
    public String getPostalCode() {
        return postalCode;
    }

    /**
     * @param postalCode the postalCode to set
     */
    public void setPostalCode(final String postalCode) {
        this.postalCode = postalCode;
    }

    /**
     * @return the latitude
     */
    public float getLatitude() {
        return latitude;
    }

    /**
     * @param latitude the latitude to set
     */
    public void setLatitude(final float latitude) {
        this.latitude = latitude;
    }

    /**
     * @return the longitude
     */
    public float getLongitude() {
        return longitude;
    }

    /**
     * @param longitude the longitude to set
     */
    public void setLongitude(final float longitude) {
        this.longitude = longitude;
    }

    /**
     * @return the dmaCode
     */
    public int getDmaCode() {
        return dmaCode;
    }

    /**
     * @param dmaCode the dmaCode to set
     */
    public void setDmaCode(final int dmaCode) {
        this.dmaCode = dmaCode;
    }

    /**
     * @return the areaCode
     */
    public int getAreaCode() {
        return areaCode;
    }

    /**
     * @param areaCode the areaCode to set
     */
    public void setAreaCode(final int areaCode) {
        this.areaCode = areaCode;
    }

    /**
     * @return the metroCode
     */
    public int getMetroCode() {
        return metroCode;
    }

    /**
     * @param metroCode the metroCode to set
     */
    public void setMetroCode(final int metroCode) {
        this.metroCode = metroCode;
    }

    /**
     * @return the ipAddress
     */
    public String getIpAddress() {
        return ipAddress;
    }

    /**
     * @param ipAddress the ipAddress to set
     */
    public void setIpAddress(final String ipAddress) {
        this.ipAddress = ipAddress;
    }

    /**
     * @return the regionName
     */
    public String getRegionName() {
        return regionName;
    }

    /**
     * @param regionName the regionName to set
     */
    public void setRegionName(final String regionName) {
        this.regionName = regionName;
    }

    /**
     * @return the timezone
     */
    public String getTimezone() {
        return timezone;
    }

    /**
     * @param timezone the timezone to set
     */
    public void setTimezone(final String timezone) {
        this.timezone = timezone;
    }

    /**
     * @return the productName
     */
    public ProductName getProductName() {
        return productName;
    }

    /**
     * @param productName the productName to set
     */
    public void setProductName(final ProductName productName) {
        this.productName = productName;
    }

    /**
     * @return the productVersion
     */
    public ProductVersion getProductVersion() {
        return productVersion;
    }

    /**
     * @param productVersion the productVersion to set
     */
    public void setProductVersion(final ProductVersion productVersion) {
        this.productVersion = productVersion;
    }
    /**
     * @return get the email address value
     */
    public String getEmail() {
        return email;
    }
    /**
     * @param email set the email address value.
     */
    public void setEmail(final String email) {
        this.email = email;
    }
    /**
     * @return the date of the record.
     */
    public Date getRecordDate() {
        return recordDate;
    }
    /**
     * @param recordDate set the date of the record.
     */
    public void setRecordDate(final Date recordDate) {
        this.recordDate = recordDate;
    }
    /**
     * @return technical attributes of the users computer.
     */
    public TechnicalAttributes getAttributes() {
        return attributes;
    }
    /**
     * @param attributes set the technical attributes of the user computer.
     */
    public void setAttributes(TechnicalAttributes attributes) {
        this.attributes = attributes;
    }
}
