/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ManagedProduct.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.geolocation.business.entity;

import java.io.Serializable;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;

/**
 *
 * @author Mathieu ANCELIN
 */
@Entity
public class ManagedProduct implements Serializable {
    /**
     * The version UID.
     */
    private static final long serialVersionUID = 1L;
    /**
     * The id of the product name.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    /**
     * The name of the managed product.
     */
    private String name;
    /**
     * The version of the managed product.
     */
    private String version;
    /**
     * @return the id of the product name.
     */
    public Long getId() {
        return id;
    }
    /**
     * Set the id of the product name.
     * @param id the id of the product name.
     */
    public void setId(final Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (id != null) {
            hash += id.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof ManagedProduct)) {
            return false;
        }
        ManagedProduct other = (ManagedProduct) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        if ((!this.name.equals(other.getName())) && (!this.version.equals(other.getVersion()))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "org.ow2.jonas.installers.geo.business.ipgeolocalisation.entity.ManagedProduct[id=" + id + "]";
    }
    /**
     * @return the name of the managed product.
     */
    public String getName() {
        return name;
    }
    /**
     * Set the name of the managed product.
     * @param name the name of the managed product.
     */
    public void setName(final String name) {
        this.name = name;
    }
    /**
     * @return the version of the managed product.
     */
    public String getVersion() {
        return version;
    }
    /**
     * Set the version of the managed product.
     * @param version the version of the managed product.
     */
    public void setVersion(final String version) {
        this.version = version;
    }
}
