/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ProductName.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.geolocation.business.entity;

import java.io.Serializable;
import java.util.List;
import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;

/**
 * The name of a product.
 * 
 * @author mancelin
 */
@Entity
public class ProductName implements Serializable {
    /**
     * The version UID.
     */
    private static final long serialVersionUID = 1L;
    /**
     * The name of the product name.
     */
    private String name = "";
    /**
     * The id of the product name.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    /**
     * The concerned list of products.
     */
    @OneToMany(mappedBy = "productName", cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    private List<GeolocalisedProduct> products;
    /**
     * @return the id of the product name.
     */
    public Long getId() {
        return id;
    }
    /**
     * Set the id of the product name.
     * @param id the id of the product name.
     */
    public void setId(final Long id) {
        this.id = id;
    }
    
    @Override
    public int hashCode() {
        int hash = 0;
        if (id != null) {
            hash += id.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof ProductName)) {
            return false;
        }
        ProductName other = (ProductName) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }
    
    @Override
    public String toString() {
        return name;
    }
    /**
     * @return the name of the product name.
     */
    public String getName() {
        return name;
    }
    /**
     * Set the name of the product name.
     * @param name the name of the product name.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * @return the products
     */
    public List<GeolocalisedProduct> getProducts() {
        return products;
    }

    /**
     * @param products the products to set
     */
    public void setProducts(final List<GeolocalisedProduct> products) {
        this.products = products;
    }
}
