/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ProductVersion.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.geolocation.business.entity;

import java.io.Serializable;
import java.util.List;
import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;

/**
 * The version of a geolocalized product.
 * 
 * @author mancelin
 */
@Entity
public class ProductVersion implements Serializable {
    /**
     * The version UID.
     */
    private static final long serialVersionUID = 1L;
    /**
     * The version of the product version.
     */
    private String version = "";
    /**
     * The id of the product version.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    /**
     * The concerned products.
     */
    @OneToMany(mappedBy = "productVersion",  cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    private List<GeolocalisedProduct> products;
    /**
     * @return the id of the product version.
     */
    public Long getId() {
        return id;
    }
    /**
     * Set the id of the product version.
     * @param id the id of the product version.
     */
    public void setId(final Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (id != null) {
            hash += id.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof ProductVersion)) {
            return false;
        }
        ProductVersion other = (ProductVersion) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return version;
    }
    /**
     * Set the version of a product version.
     * @param version the version of a product version.
     */
    public void setVersion(final String version) {
        this.version = version;
    }
    /**
     * @return the version of a product version.
     */
    public String getVersion() {
        return version;
    }
    /**
     * @return the products
     */
    public List<GeolocalisedProduct> getProducts() {
        return products;
    }
    /**
     * @param products the products to set
     */
    public void setProducts(final List<GeolocalisedProduct> products) {
        this.products = products;
    }
}
