/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TechnicalAttributes.java 5338 2010-02-16 09:29:44Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.geolocation.business.entity;

import java.io.Serializable;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;

/**
 * Entity class for technical specification of users computer.
 * 
 * @author Mathieu ANCELIN
 */
@Entity
public class TechnicalAttributes implements Serializable {
    /**
     * The version UID.
     */
    private static final long serialVersionUID = 1L;
    /**
     * The id of the product name.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    /**
     * The number of processors.
     */
    private String numProc;
    /**
     * The jre version.
     */
    private String jreVersion;
    /**
     * The jre vendor name.
     */
    private String jreVendor;
    /**
     * The JVM version.
     */
    private String jvmVersion;
    /**
     * The JVM vendor name.
     */
    private String jvmVendor;
    /**
     * The JVM name.
     */
    private String jvmName;
    /**
     * The OS name.
     */
    private String osName;
    /**
     * The OS architecture.
     */
    private String osArch;
    /**
     * The version of the OS.
     */
    private String osVersion;
    /**
     * @return the id of the product name.
     */
    public Long getId() {
        return id;
    }
    /**
     * Set the id of the product name.
     * @param id the id of the product name.
     */
    public void setId(final Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (id != null) {
            hash += id.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof ProductName)) {
            return false;
        }
        TechnicalAttributes other = (TechnicalAttributes) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "org.ow2.util.geolocation.business.entity.TechnicalAttributes[id=" + id + "]";
    }
    /**
     * @return the jre vendor.
     */
    public String getJreVendor() {
        return jreVendor;
    }
    /**
     *
     * @param jreVendor the jre vendor.
     */
    public void setJreVendor(final String jreVendor) {
        this.jreVendor = jreVendor;
    }
    /**
     *
     * @return the jre version.
     */
    public String getJreVersion() {
        return jreVersion;
    }
    /**
     *
     * @param jreVersion the jre version.
     */
    public void setJreVersion(final String jreVersion) {
        this.jreVersion = jreVersion;
    }
    /**
     *
     * @return the jvm name
     */
    public String getJvmName() {
        return jvmName;
    }
    /**
     *
     * @param jvmName the jvm name.
     */
    public void setJvmName(final String jvmName) {
        this.jvmName = jvmName;
    }
    /**
     *
     * @return the jvm vendor name.
     */
    public String getJvmVendor() {
        return jvmVendor;
    }
    /**
     *
     * @param jvmVendor the jvm vendor name.
     */
    public void setJvmVendor(final String jvmVendor) {
        this.jvmVendor = jvmVendor;
    }
    /**
     *
     * @return the jvm verison.
     */
    public String getJvmVersion() {
        return jvmVersion;
    }
    /**
     *
     * @param jvmVersion the jvm version.
     */
    public void setJvmVersion(final String jvmVersion) {
        this.jvmVersion = jvmVersion;
    }
    /**
     *
     * @return the number of processors.
     */
    public String getNumProc() {
        return numProc;
    }
    /**
     *
     * @param numProc the number of processors.
     */
    public void setNumProc(final String numProc) {
        this.numProc = numProc;
    }
    /**
     *
     * @return the os architecture.
     */
    public String getOsArch() {
        return osArch;
    }
    /**
     *
     * @param osArch set the os architecture.
     */
    public void setOsArch(final String osArch) {
        this.osArch = osArch;
    }
    /**
     *
     * @return the os name.
     */
    public String getOsName() {
        return osName;
    }
    /**
     *
     * @param osName set the os name.
     */
    public void setOsName(final String osName) {
        this.osName = osName;
    }
    /**
     *
     * @return the os version
     */
    public String getOsVersion() {
        return osVersion;
    }
    /**
     * 
     * @param osVersion set the os version.
     */
    public void setOsVersion(final String osVersion) {
        this.osVersion = osVersion;
    }

}
